@@ -108,8 +108,8 @@ typedef struct _AFS_COMM_RESULT_BLOCK
 //
 
 #define AFS_REDIR_INIT_FLAG_HIDE_DOT_FILES          0x00000001
-
 #define AFS_REDIR_INIT_NO_PAGING_FILE               0x00000002
+#define AFS_REDIR_INIT_FLAG_DISABLE_SHORTNAMES	    0x00000004
 
 typedef struct _AFS_REDIR_INIT_INFO_CB
 {
@@ -602,6 +602,39 @@ typedef struct _AFS_FILE_RENAME_RESULT_CB
 } AFSFileRenameResultCB;
 
 
+//
+// File Hard Link CB
+//
+
+typedef struct _AFS_FILE_HARDLINK_CB
+{
+
+    AFSFileID       SourceParentId;        /* Must be directory */
+
+    AFSFileID       TargetParentId;        /* Must be directory */
+
+    BOOLEAN         bReplaceIfExists;
+
+                                           /* Source Name and FileID in Common Request Block */
+
+    USHORT          TargetNameLength;
+
+    WCHAR           TargetName[ 1];
+
+} AFSFileHardLinkCB;
+
+typedef struct _AFS_FILE_HARDLINK_RESULT_CB
+{
+
+    LARGE_INTEGER   SourceParentDataVersion;
+
+    LARGE_INTEGER   TargetParentDataVersion;
+
+    AFSDirEnumEntry DirEnum;
+
+} AFSFileHardLinkResultCB;
+
+
 //
 // Control structures for AFS_REQUEST_TYPE_EVAL_TARGET_BY_ID
 // and AFS_REQUEST_TYPE_EVAL_TARGET_BY_NAME
