@@ -1080,7 +1080,7 @@ AFSPrimaryVolumeWorkerThread( IN PVOID Context)
                                   TRUE);
 
                 if( pVolumeCB->ObjectInfoListHead == NULL &&
-                    pVolumeCB->DirectoryCB->OpenReferenceCount == 0 &&
+                    pVolumeCB->DirectoryCB->DirOpenReferenceCount <= 0 &&
                     pVolumeCB->VolumeReferenceCount == 1 &&
                     ( pVolumeCB->RootFcb == NULL ||
                       pVolumeCB->RootFcb->OpenReferenceCount == 0) &&
@@ -1191,10 +1191,7 @@ AFSPrimaryVolumeWorkerThread( IN PVOID Context)
                                 AFSAcquireExcl( &pCurrentObject->NonPagedInfo->ObjectInfoLock,
                                                 TRUE);
 
-                                if ( pCurrentObject->ObjectReferenceCount <= 0 &&
-                                     ( pCurrentObject->Fcb == NULL ||
-                                       pCurrentObject->Fcb->OpenReferenceCount == 0 &&
-                                       pCurrentObject->Fcb->Specific.File.ExtentCount == 0))
+                                if ( pCurrentObject->ObjectReferenceCount <= 0)
                                 {
 
                                     AFSRemoveFcb( &pCurrentObject->Fcb);
@@ -1275,7 +1272,7 @@ AFSPrimaryVolumeWorkerThread( IN PVOID Context)
                         while( pCurrentDirEntry != NULL)
                         {
 
-                            if( pCurrentDirEntry->OpenReferenceCount > 0 ||
+                            if( pCurrentDirEntry->DirOpenReferenceCount > 0 ||
                                 ( pCurrentDirEntry->ObjectInformation->Fcb != NULL &&
                                   pCurrentDirEntry->ObjectInformation->Fcb->OpenReferenceCount > 0) ||
                                 liCurrentTime.QuadPart <= pCurrentDirEntry->ObjectInformation->LastAccessCount.QuadPart ||
@@ -1340,7 +1337,7 @@ AFSPrimaryVolumeWorkerThread( IN PVOID Context)
                                 while( pCurrentDirEntry != NULL)
                                 {
 
-                                    if( pCurrentDirEntry->OpenReferenceCount > 0 ||
+                                    if( pCurrentDirEntry->DirOpenReferenceCount > 0 ||
                                         ( pCurrentDirEntry->ObjectInformation->Fcb != NULL &&
                                           pCurrentDirEntry->ObjectInformation->Fcb->OpenReferenceCount > 0) ||
                                         liCurrentTime.QuadPart <= pCurrentDirEntry->ObjectInformation->LastAccessCount.QuadPart ||
@@ -1383,7 +1380,7 @@ AFSPrimaryVolumeWorkerThread( IN PVOID Context)
 
                                     pFcb = NULL;
 
-                                    AFSDbgLogMsg( AFS_SUBSYSTEM_CLEANUP_PROCESSING,
+                                    AFSDbgLogMsg( AFS_SUBSYSTEM_CLEANUP_PROCESSING | AFS_SUBSYSTEM_DIRENTRY_REF_COUNTING,
                                                   AFS_TRACE_LEVEL_VERBOSE,
                                                   "AFSPrimaryVolumeWorkerThread Deleting DE %wZ Object %08lX\n",
                                                   &pCurrentDirEntry->NameInformation.FileName,
@@ -1440,10 +1437,7 @@ AFSPrimaryVolumeWorkerThread( IN PVOID Context)
                                     AFSAcquireExcl( &pCurrentChildObject->NonPagedInfo->ObjectInfoLock,
                                                     TRUE);
 
-                                    if( pCurrentChildObject->ObjectReferenceCount <= 0 &&
-                                        ( pCurrentChildObject->Fcb == NULL ||
-                                          pCurrentChildObject->Fcb->OpenReferenceCount == 0 &&
-                                          pCurrentChildObject->Fcb->Specific.File.ExtentCount == 0))
+                                    if( pCurrentChildObject->ObjectReferenceCount <= 0)
                                     {
 
                                         AFSRemoveFcb( &pCurrentChildObject->Fcb);
@@ -1567,12 +1561,11 @@ AFSPrimaryVolumeWorkerThread( IN PVOID Context)
                     else if( pCurrentObject->FileType == AFS_FILE_TYPE_FILE)
                     {
 
-                        AFSReleaseResource( pVolumeCB->ObjectInfoTree.TreeLock);
-
                         lCount = AFSObjectInfoIncrement( pCurrentObject);
 
-                        if( lCount == 0 &&
-                            pCurrentObject->Fcb != NULL)
+                        AFSReleaseResource( pVolumeCB->ObjectInfoTree.TreeLock);
+
+                        if( pCurrentObject->Fcb != NULL)
                         {
 
                             //
@@ -1605,10 +1598,7 @@ AFSPrimaryVolumeWorkerThread( IN PVOID Context)
                                         TRUE);
 
                         if( BooleanFlagOn( pCurrentObject->Flags, AFS_OBJECT_FLAGS_DELETED) &&
-                            pCurrentObject->ObjectReferenceCount <= 0 &&
-                            ( pCurrentObject->Fcb == NULL ||
-                              pCurrentObject->Fcb->OpenReferenceCount == 0 &&
-                              pCurrentObject->Fcb->Specific.File.ExtentCount == 0))
+                            pCurrentObject->ObjectReferenceCount <= 0)
                         {
 
                             AFSRemoveFcb( &pCurrentObject->Fcb);
